[or-cvs] Add the output of OSX arch into the package name in prepara...

phobos at seul.org phobos at seul.org
Tue Jul 18 04:37:46 UTC 2006


Update of /home/or/cvsroot/tor/contrib/osx
In directory moria:/tmp/cvs-serv16790

Modified Files:
	package.sh 
Log Message:
Add the output of OSX arch into the package name in preparation for ppc
vs x86 packages.


Index: package.sh
===================================================================
RCS file: /home/or/cvsroot/tor/contrib/osx/package.sh,v
retrieving revision 1.29
retrieving revision 1.30
diff -u -p -d -r1.29 -r1.30
--- package.sh	17 Jul 2006 04:31:22 -0000	1.29
+++ package.sh	18 Jul 2006 04:37:43 -0000	1.30
@@ -25,12 +25,19 @@ PRIVOXY_PKG_ZIP=~/tmp/privoxyosx_setup_3
 #   http://developer.apple.com/documentation/DeveloperTools/Conceptual/SoftwareDistribution/index.html
 #   man packagemaker
 
 # Make sure VERSION is set, so we don't name the package "Tor--$OS-Bundle.dmg"
 if [ "XX$VERSION" = 'XX' ]; then
   echo "VERSION not set."
   exit 1
 fi
 
+if [ -x /usr/bin/arch ]; then
+  ARCH=`/usr/bin/arch`
+else
+  ARCH="unknown"
+fi
+
 ## Determine OSX Version
 # map version to name
 if [ -x /usr/bin/sw_vers ]; then
@@ -151,7 +158,7 @@ fi
 ### Assemble the metapackage.  Packagemaker won't buld metapackages from
 # the command line, so we need to do it by hand.
 
-MPKG=$BUILD_DIR/output/Tor-$VERSION-$OS-Bundle.mpkg
+MPKG=$BUILD_DIR/output/Tor-$VERSION-$OS-$ARCH-Bundle.mpkg
 mkdir -p "$MPKG/Contents/Resources"
 echo -n "pmkrpkg1" > "$MPKG/Contents/PkgInfo"
 cp contrib/osx/ReadMe.rtf "$MPKG/Contents/Resources"
@@ -178,10 +185,10 @@ cp LICENSE $BUILD_DIR/output/Tor\ Licens
 
 find $BUILD_DIR/output -print0 | sudo xargs -0 chown root:wheel
 
-mv $BUILD_DIR/output "$BUILD_DIR/Tor-$VERSION-$OS-Bundle"
-rm -f "Tor-$VERSION-$OS-Bundle.dmg"
+mv $BUILD_DIR/output "$BUILD_DIR/Tor-$VERSION-$OS-$ARCH-Bundle"
+rm -f "Tor-$VERSION-$OS-$ARCH-Bundle.dmg"
 USER="`whoami`"
-sudo hdiutil create -format UDZO -srcfolder "$BUILD_DIR/Tor-$VERSION-$OS-Bundle" "Tor-$VERSION-$OS-Bundle.dmg"
-sudo chown "$USER" "Tor-$VERSION-$OS-Bundle.dmg"
+sudo hdiutil create -format UDZO -srcfolder "$BUILD_DIR/Tor-$VERSION-$OS-$ARCH-Bundle" "Tor-$VERSION-$OS-$ARCH-Bundle.dmg"
+sudo chown "$USER" "Tor-$VERSION-$OS-$ARCH-Bundle.dmg"
 
 sudo rm -rf $BUILD_DIR
@@ -25,12 +25,19 @@ PRIVOXY_PKG_ZIP=~/tmp/privoxyosx_setup_3
 #   man packagemaker
 
-# Make sure VERSION is set, so we don't name the package "Tor--$OS-Bundle.dmg"
+# Make sure VERSION is set, so we don't name the package
+# "Tor--$OS-$ARCH-Bundle.dmg"
 if [ "XX$VERSION" = 'XX' ]; then
   echo "VERSION not set."



More information about the tor-commits mailing list